From 81d79a79e4b29e9314b64b2e4c49b48ae8319767 Mon Sep 17 00:00:00 2001
From: ftimme <ft@falkotimme.com>
Date: Tue, 11 Oct 2011 08:50:45 -0400
Subject: [PATCH] - WebDAV Users: show only domains that run on Apache (because nginx does not have full WebDAV support).

---
 interface/web/sites/web_subdomain_edit.php |   37 +++++++++++++++++++++----------------
 1 files changed, 21 insertions(+), 16 deletions(-)

diff --git a/interface/web/sites/web_subdomain_edit.php b/interface/web/sites/web_subdomain_edit.php
index 91a84d1..e290281 100644
--- a/interface/web/sites/web_subdomain_edit.php
+++ b/interface/web/sites/web_subdomain_edit.php
@@ -41,11 +41,8 @@
 require_once('../../lib/config.inc.php');
 require_once('../../lib/app.inc.php');
 
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'sites')) {
-	header("Location: ../index.php");
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('sites');
 
 // Loading classes
 $app->uses('tpl,tform,tform_actions');
@@ -53,22 +50,18 @@
 
 class page_action extends tform_actions {
 	
+	var $parent_domain_record;
+	
 	function onShowNew() {
 		global $app, $conf;
 		
 		// we will check only users, not admins
 		if($_SESSION["s"]["user"]["typ"] == 'user') {
-			
-			// Get the limits of the client
-			$client_group_id = $_SESSION["s"]["user"]["default_group"];
-			$client = $app->db->queryOneRecord("SELECT limit_web_subdomain FROM sys_group, client WHERE sys_group.client_id = client.client_id and sys_group.groupid = $client_group_id");
-			
-			// Check if the user may add another maildomain.
-			if($client["limit_web_subdomain"] >= 0) {
-				$tmp = $app->db->queryOneRecord("SELECT count(domain_id) as number FROM web_domain WHERE sys_groupid = $client_group_id and type = 'subdomain'");
-				if($tmp["number"] >= $client["limit_web_subdomain"]) {
-					$app->error($app->tform->wordbook["limit_web_subdomain_txt"]);
-				}
+			if(!$app->tform->checkClientLimit('limit_web_subdomain',"type = 'subdomain'")) {
+				$app->error($app->tform->wordbook["limit_web_subdomain_txt"]);
+			}
+			if(!$app->tform->checkResellerLimit('limit_web_subdomain',"type = 'subdomain'")) {
+				$app->error('Reseller: '.$app->tform->wordbook["limit_web_subdomain_txt"]);
 			}
 		}
 		
@@ -100,10 +93,22 @@
 		$this->dataRecord["server_id"] = $parent_domain["server_id"];
 		$this->dataRecord["domain"] = $this->dataRecord["domain"].'.'.$parent_domain["domain"];
 		
+		$this->parent_domain_record = $parent_domain;
+		
+		//* make sure that the email domain is lowercase
+		if(isset($this->dataRecord["domain"])) $this->dataRecord["domain"] = strtolower($this->dataRecord["domain"]);
 		
 		parent::onSubmit();
 	}
 	
+	function onAfterInsert() {
+		global $app, $conf;
+		
+		$app->db->query('UPDATE web_domain SET sys_groupid = '.intval($this->parent_domain_record['sys_groupid']).' WHERE domain_id = '.$this->id);
+		
+	}
+	
+	
 }
 
 $page = new page_action;

--
Gitblit v1.9.1